@@ -4,16 +4,18 @@ from contextlib import contextmanager
 from uuid import UUID
 from shared_context.domain.model import AggregateRoot, Repository as BaseRepository
 from sqlalchemy import create_engine
-from sqlalchemy.orm import sessionmaker
+from sqlalchemy.orm import sessionmaker, scoped_session
 from sqlalchemy.dialects.mysql import BINARY
 from sqlalchemy.types import TypeDecorator
 
 
 @contextmanager
 def session_scope(dsn: str):
-    Session = sessionmaker(bind=create_engine(dsn))
+    session_factory = sessionmaker(bind=create_engine(dsn))
 
+    Session = scoped_session(session_factory)
     session = Session()
+
     try:
         yield session
 
@@ -23,7 +25,9 @@ def session_scope(dsn: str):
 
         raise
     finally:
+        session.expunge_all()
         session.close()
+        Session.remove()
 
 
 class SessionBuilder:
@@ -59,13 +63,13 @@ class Repository(BaseRepository):
         with session_scope(self._dsn) as session:
             result = session.query(self.__aggregate).filter_by(**kwargs).first()
 
-        return result
+            return result
 
     def find_all(self, **kwargs) -> List[AggregateRoot]:
         with session_scope(self._dsn) as session:
             results = session.query(self.__aggregate).filter_by(**kwargs).all()
 
-        return results
+            return results
 
 
 class Orm(metaclass=abc.ABCMeta):
